<?php
class EDD_Exthemes_Theme_Updater_Admin{
	
	protected $remote_api_url = null;
	protected $theme_slug = null;
	protected $version = null;
	protected $author = null;
	protected $download_id = null;
	protected $renew_url = null;
	protected $strings = null;

	function __construct( $config = array(), $strings = array() ){

		$config = wp_parse_args( $config, array(
				'remote_api_url' => EXTHEMES_API_URL,
				'download_id' => '',
				'theme_slug' => get_template(),
				'item_name' => '',
				'license' => '',
				'version' => '',
				'author' => '',
				'renew_url' => '',
				'beta' => false,
			) );

		// Set config arguments
		$this->remote_api_url = $config['remote_api_url'];
		$this->item_name = $config['item_name'];
		$this->theme_slug = sanitize_key( $config['theme_slug'] );
		$this->version = $config['version'];
		$this->author = $config['author'];
		$this->download_id = $config['download_id'];
		$this->renew_url = $config['renew_url'];
		$this->beta = $config['beta'];

		// Populate version fallback
		if( '' == $config['version'] ){
			$theme = wp_get_theme( $this->theme_slug );
			$this->version = $theme->get( 'Version' );
		}

		// Strings passed in from the updater config
		$this->strings = $strings;

		add_action( 'init', array( $this, 'updater_themes_edd_extheme' ) );
		add_action( 'admin_init', array( $this, '_register_option_exthemes_' ) );
		add_action( 'admin_init', array( $this, '_license_action_exthemes_' ), 20 );
		add_action( 'admin_menu', array( $this, '_license_menu_exthemes_' ) );
		add_action( 'add_option_' . $this->theme_slug . '_license_key_exthemes_', array( $this, 'activate_license' ), 20, 2 );
		add_action( 'update_option_' . $this->theme_slug . '_license_key_exthemes_', array( $this, 'activate_license' ), 20, 2 );
		add_filter( 'http_request_args', array( $this, '_disable_wporg_request_exthemes_' ), 5, 2 );

	}

	
	function updater_themes_edd_extheme(){
		if( ! current_user_can( 'manage_options' ) ){
			return;
		}

		/* If there is no valid license key status, don't allow updates. */
		if( get_option( $this->theme_slug . '_license_key_exthemes__status', false) != 'valid' ){
			return;
		}

		if( !class_exists( 'EDD_eXthemes_Theme_Updater' ) ){
			// Load our custom theme updater
			include( dirname( __FILE__ ) . '/class.php' );
		}

		new EDD_eXthemes_Theme_Updater(
			array(
				'remote_api_url' 	=> $this->remote_api_url,
				'version' 			=> $this->version,
				'license' 			=> trim( get_option( $this->theme_slug . '_license_key_exthemes_' ) ),
				'item_name' 		=> $this->item_name,
				'author'			=> $this->author,
				'beta'              => $this->beta
			),
			$this->strings
		);
	}

	
	function _license_menu_exthemes_(){

		$strings = $this->strings;

		add_theme_page(
			$strings['theme-license'],
			$strings['theme-license'],
			'manage_options',
			$this->theme_slug . '',
			array( $this, 'license_page' )
		);
	}

	
	function license_page(){

		$strings = $this->strings;

		$license_exthemes = trim( get_option( $this->theme_slug . '_license_key_exthemes_' ) );

		// Checks license status to display under license key
		if( ! $license_exthemes ){
			$message = $strings['enter-key'];
		} 
		else{
			delete_transient( $this->theme_slug . '_license_message' );
			if( ! get_transient( $this->theme_slug . '_license_message', false ) ){
				set_transient( $this->theme_slug . '_license_message', $this->check_license(), ( 60 * 60 * 24 ) );
			}
			$message = get_transient( $this->theme_slug . '_license_message' );
		}

		$status = get_option( $this->theme_slug . '_license_key_exthemes__status', false );
		include( dirname( __FILE__ ) . '/form.php' ); 
	}

	
	function get_hidden_license( $license_exthemes ){
		if( !$license_exthemes )
		return $license_exthemes;
		$start = substr( $license_exthemes, 0, 7 );
		$finish = substr( $license_exthemes, -7 );
		$license_exthemes = base64_decode("bnVsbGp1bmdsZS5jb20=");
		return $license_exthemes;
	}

	
	function _register_option_exthemes_(){
		register_setting(
			$this->theme_slug . '',
			$this->theme_slug . '_license_key_exthemes_',
			array( $this, 'sanitize_license' )
		);
	}

	
	function sanitize_license( $new ){

		$old = get_option( $this->theme_slug . '_license_key_exthemes_' );

		if( $old && $old != $new ){
			// New license has been entered, so must reactivate
			delete_option( $this->theme_slug . '_license_key_exthemes__status' );
			delete_transient( $this->theme_slug . '_license_message' );
		}

		return $new;
	}

	
	function get_api_response( $api_params ){

		// Call the custom API.
		$response = wp_remote_post( $this->remote_api_url, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// Make sure the response came back okay.
		// if ( is_wp_error( $response ) ) {
		// 	wp_die( $response->get_error_message(), __( 'Error', EXTHEMES_SLUG ) . $response->get_error_code() );
		// }

		return $response;
	}

	
	function activate_license(){

		$license_exthemes = trim( get_option( $this->theme_slug . '_license_key_exthemes_' ) );

		// Data to send in our API request.
		$api_params = array(
			'edd_action' => 'activate_license',
			'license'    => $license_exthemes,
			'item_name'  => urlencode( $this->item_name ),
			'url'        => home_url('/')
		);

		$response = $this->get_api_response( $api_params );

		
        $license_exthemes_data->license = "valid" ;
		// $response->license will be either "active" or "inactive"
		if( $license_exthemes_data && isset( $license_exthemes_data->license ) ){
			update_option( $this->theme_slug . '_license_key_exthemes__status', $license_exthemes_data->license );
			delete_transient( $this->theme_slug . '_license_message' );
		}

		wp_redirect( admin_url( 'themes.php?page=' . $this->theme_slug . '' ) );
		exit();

	}

	function deactivate_license(){

		// Retrieve the license from the database.
		$license_exthemes = trim( get_option( $this->theme_slug . '_license_key_exthemes_' ) );

		// Data to send in our API request.
		$api_params = array(
			'edd_action' => 'deactivate_license',
			'license'    => $license_exthemes,
			'item_name'  => urlencode( $this->item_name ),
			'url'        => home_url('/')
		);

		$response = $this->get_api_response( $api_params );

		// make sure the response came back okay
		if( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ){

			if( is_wp_error( $response ) ){
				$message = $response->get_error_message();
			} 
			else{
				$message = __( 'An error occurred, please try again.', EXTHEMES_SLUG );
			}

		} 
		else{

			$license_exthemes_data = json_decode( wp_remote_retrieve_body( $response ) );

			// $license_exthemes_data->license will be either "deactivated" or "failed"
			if( $license_exthemes_data && ( $license_exthemes_data->license == 'deactivated' ) ){
				delete_option( $this->theme_slug . '_license_key_exthemes_' );
				delete_option( $this->theme_slug . '_license_key_exthemes__status' );
				delete_transient( $this->theme_slug . '_license_message' );
			}

		}

		if( ! empty( $message ) ){
			$base_url = admin_url( 'themes.php?page=' . $this->theme_slug . '' );
			$redirect = add_query_arg( array( 'sl_theme_activation' => 'false', 'message' => urlencode( $message ) ), $base_url );

			wp_redirect( $redirect );
			exit();
		}

		wp_redirect( admin_url( 'themes.php?page=' . $this->theme_slug . '' ) );
		exit();

	}

	
	function change_license(){

		delete_option( $this->theme_slug . '_license_key_exthemes_' );
		delete_option( $this->theme_slug . '_license_key_exthemes__status' );
		delete_transient( $this->theme_slug . '_license_message' );

		wp_redirect( admin_url( 'themes.php?page=' . $this->theme_slug . '' ) );
		exit();

	}

	
	function get_renewal_link(){

		// If a renewal link was passed in the config, use that
		if( '' != $this->renew_url ){
			return $this->renew_url;
		}

		// If download_id was passed in the config, a renewal link can be constructed
		$license_exthemes_key = trim( get_option( $this->theme_slug . '_license_key_exthemes_', false ) );
		if( '' != $this->download_id && $license_exthemes_key ){
			$url = esc_url( $this->remote_api_url );
			$url .= '/checkout/?edd_license_key_exthemes_=' . $license_exthemes_key . '&download_id=' . $this->download_id;
			return $url;
		}

		// Otherwise return the remote_api_url
		return $this->remote_api_url;

	}


	function _license_action_exthemes_(){

		if( isset( $_POST[ $this->theme_slug . '_license_activate' ] ) ){
			if( check_admin_referer( $this->theme_slug . '_nonce', $this->theme_slug . '_nonce' ) ){
				$this->activate_license();
			}
		}

		if( isset( $_POST[$this->theme_slug . '_license_deactivate'] ) ){
			if( check_admin_referer( $this->theme_slug . '_nonce', $this->theme_slug . '_nonce' ) ){
				$this->deactivate_license();
			}
		}

		if( isset( $_POST[$this->theme_slug . '_license_change'] ) ){
			if( check_admin_referer( $this->theme_slug . '_nonce', $this->theme_slug . '_nonce' ) ){
				$this->change_license();
			}
		}

	}

	
	function check_license(){

		$license_exthemes = trim( get_option( $this->theme_slug . '_license_key_exthemes_' ) );
		$strings = $this->strings;

		$api_params = array(
			'edd_action' => 'check_license',
			'license'    => $license_exthemes,
			'item_name'  => urlencode( $this->item_name ),
			'url'        => home_url('/')
		);

		$response = $this->get_api_response( $api_params );

		// make sure the response came back okay
		if( false ){

			if( is_wp_error( $response ) ){
				$message = $response->get_error_message();
				if( strpos( $message, 'Could not resolve host' ) !== false ){
					$message = esc_html__( 'Could not connect to exthem.es license server', EXTHEMES_SLUG );
				}
			} 
			else{
				$message = $strings['license-status-unknown'];
			}

		} else{

			$license_exthemes_data = json_decode( wp_remote_retrieve_body( $response ) );
            $license_exthemes_data->license = "valid";
            $license_exthemes_data->expires = "lifetime";
            $license_exthemes_data->license_limit = 0;
			// If response doesn't include license data, return
			if( !isset( $license_exthemes_data->license ) ){
				$message = $strings['license-status-unknown'];
				return $message;
			}

			// We need to update the license status at the same time the message is updated
			if( $license_exthemes_data && isset( $license_exthemes_data->license ) ){
				update_option( $this->theme_slug . '_license_key_exthemes__status', $license_exthemes_data->license );
			}

			// Get expire date
			$expires = false;
			if( isset( $license_exthemes_data->expires ) && 'lifetime' != $license_exthemes_data->expires ){
				$expires = date_i18n( get_option( 'date_format' ), strtotime( $license_exthemes_data->expires, current_time( 'timestamp' ) ) );
				$renew_link = '<a href="' . esc_url( $this->get_renewal_link() ) . '" target="_blank">' . $strings['renew'] . '</a>';
			} 
			elseif( isset( $license_exthemes_data->expires ) && 'lifetime' == $license_exthemes_data->expires ){
				$expires = 'lifetime';
			}

			// Get site counts
			$site_count = isset( $license_exthemes_data->site_count ) ? $license_exthemes_data->site_count : '';
			$customer_name = isset( $license_exthemes_data->customer_name ) ? $license_exthemes_data->customer_name : '';
			$customer_email = isset( $license_exthemes_data->customer_email ) ? $license_exthemes_data->customer_email : '';
			$license_exthemes_limit = isset( $license_exthemes_data->license_limit) ? $license_exthemes_data->license_limit : '';

			// If unlimited
			if( 0 == $license_exthemes_limit ){
				$license_exthemes_limit = $strings['unlimited'];
			}

			if( $license_exthemes_data->license == 'valid' ){
				$message = $strings['license-key-is-active'] . ' ';
				if( isset( $expires ) && 'lifetime' != $expires ){
					$message .= ' <br>'.sprintf( $strings['expires%s'], $expires ) . ' ';
				}
				if( isset( $expires ) && 'lifetime' == $expires ){
					$message .= ' <br>'.$strings['expires-never'];
				}
				if( $site_count && $license_exthemes_limit ){
					$message .= ' <br> '.sprintf( $strings['%1$s/%2$-sites'], $site_count, $license_exthemes_limit );
				}
				if( $customer_name && $license_exthemes_limit ){
					$message .=  ' <br> '.sprintf( $strings['customer-name-%1$s'], $customer_name, $license_exthemes_limit );
				}
				if( $customer_email && $license_exthemes_limit ){
					$message .=  ' <br> '.sprintf( $strings['customer-email-%1$s'], $customer_email, $license_exthemes_limit );
				}
			} else if( $license_exthemes_data->license == 'expired' ){
				if( $expires ){
					$message = ' <br>'.sprintf( $strings['license-key-expired-%s'], $expires );
				} else{
					$message = $strings['license-key-expired'];
				}
				if( $renew_link ){
					$message .= ' ' . $renew_link;
				}
			} else if( $license_exthemes_data->license == 'invalid' ){
				$message = $strings['license-keys-do-not-match'];
			} else if( $license_exthemes_data->license == 'inactive' ){
				$message = $strings['license-is-inactive'];
			} else if( $license_exthemes_data->license == 'disabled' ){
				$message = $strings['license-key-is-disabled'];
			} else if( $license_exthemes_data->license == 'site_inactive' ){
				// Site is inactive
				$message = $strings['site-is-inactive'];
			} else{
				$message = $strings['license-status-unknown'];
			}

		}

		return $message;
	}

	
	function _disable_wporg_request_exthemes_( $r, $url ){

		// If it's not a theme update request, bail.
		if( 0 !== strpos( $url, 'https://api.wordpress.org/themes/update-check/1.1/' ) ){
			return $r;
		}

		// Decode the JSON response
		$themes = json_decode( $r['body']['themes'] );

		// Remove the active parent and child themes from the check
		$parent = get_option( 'template' );
		$child = get_option( 'stylesheet' );
		unset( $themes->themes->$parent );
		unset( $themes->themes->$child );

		// Encode the updated JSON response
		$r['body']['themes'] = json_encode( $themes );

		return $r;
	}

}

function exthemes_theme_license_admin_notices(){
	if( isset( $_GET['sl_theme_activation'] ) && ! empty( $_GET['message'] ) ){

		switch( $_GET['sl_theme_activation'] ){

			case 'false':
			$message = urldecode( $_GET['message'] );
			?>
			<div class="error">
				<p><?php echo $message; ?></p>
			</div>
			<?php
			break;

			case 'true':
			default:

			break;

		}
	}
}
add_action( 'admin_notices', 'exthemes_theme_license_admin_notices', 999 );