<?php

/**
* ReduxFramework Barebones Sample Config File
* For full documentation, please visit: http://docs.reduxframework.com/
*/

if ( ! class_exists( 'Redux' ) ) {
	return;
}

// This is your option name where all the Redux data is stored.
$opt_name = "opt_themes";

/**
* ---> SET ARGUMENTS
* All the possible arguments for Redux.
* For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
* */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
// TYPICAL -> Change these values as you need/desire
'opt_name'             => $opt_name,
// This is where your data is stored in the database and also becomes your global variable name.
'display_name'         => '<span class="dashicons dashicons-share-alt"></span> '.$theme->get( 'Name' ).'',
// Name that appears at the top of your panel
'display_version'      => $theme->get( 'Version' ),
// Version that appears at the top of your panel
'menu_type'            => 'menu',
//Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
'allow_sub_menu'       => true,
// Show the sections below the admin menu item or not
'menu_title'           => __( ''.$theme->get( 'Name' ).' '.$theme->get( 'Version' ).'', 'moddroid' ),
'page_title'           => __( ''.$theme->get( 'Name' ).' '.$theme->get( 'Version' ).'', 'moddroid' ),
// You will need to generate a Google API key to use this feature.
// Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
'google_api_key'       => '',
// Set it you want google fonts to update weekly. A google_api_key value is required.
'google_update_weekly' => false,
// Must be defined to add google fonts to the typography module
'async_typography'     => true,
// Use a asynchronous font on the front end or font string
//'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
'admin_bar'            => true,
// Show the panel pages on the admin bar dashicons-share-alt dashicons-dashboard
'admin_bar_icon'       => 'dashicons-admin-multisite',
// Choose an icon for the admin bar menu
'admin_bar_priority'   => 50,
// Choose an priority for the admin bar menu
'global_variable'      => '',
// Set a different name for your global variable other than the opt_name
'dev_mode'             => false,
// Show the time the page took to load, etc
'update_notice'        => false,
// If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
'customizer'           => false,
// Enable basic customizer support
//'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
//'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

// OPTIONAL -> Give you extra features
'page_priority'        => null,
// Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
'page_parent'          => 'themes.php',
// For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
'page_permissions'     => 'manage_options',
// Permissions needed to access the options panel.
'menu_icon'            => 'dashicons-admin-multisite',
// Specify a custom URL to an icon
'last_tab'             => '',
// Force your panel to always open to a specific tab (by id)
'page_icon'            => 'icon-themes',
// Icon displayed in the admin panel next to your menu_title
'page_slug'            => '_options',
// Page slug used to denote the panel
'save_defaults'        => true,
// On load save the defaults to DB before user clicks save or not
'default_show'         => false,
// If true, shows the default value next to each field that is not the default value.
'default_mark'         => '',
// What to print by the field's title if the value shown is default. Suggested: *
'show_import_export'   => true,
// Shows the Import/Export panel when not used as a field.

// CAREFUL -> These options are for advanced use only
'transient_time'       => 60 * MINUTE_IN_SECONDS,
'output'               => true,
// Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
'output_tag'           => true,
// Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
// 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

// FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
'database'             => '',
// possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

'use_cdn'              => true,
// If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

//'compiler'             => true,

// HINTS
'hints'                => array(
'icon'          => 'el el-question-sign',
'icon_position' => 'right',
'icon_color'    => 'lightgray',
'icon_size'     => 'normal',
'tip_style'     => array(
'color'   => 'light',
'shadow'  => true,
'rounded' => false,
'style'   => '',
),
'tip_position'  => array(
'my' => 'top left',
'at' => 'bottom right',
),
'tip_effect'    => array(
'show' => array(
'effect'   => 'slide',
'duration' => '500',
'event'    => 'mouseover',
),
'hide' => array(
'effect'   => 'slide',
'duration' => '500',
'event'    => 'click mouseleave',
),
),
)
);

// ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.

$args['admin_bar_links'][] = array(
'id'    => 'redux-docs',
'href'  => 'https://exthem.es/',
'title' => __( 'by ex-themes', 'moddroid' ),
);
/*
$args['admin_bar_links'][] = array(
//'id'    => 'redux-support',
'href'  => 'https://github.com/ReduxFramework/redux-framework/issues',
'title' => __( 'Support', 'moddroid' ),
);

$args['admin_bar_links'][] = array(
'id'    => 'redux-extensions',
'href'  => 'reduxframework.com/extensions',
'title' => __( 'Extensions', 'moddroid' ),
);

*/
// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
$args['share_icons'][] = array(
'url'   => 'https://web.facebook.com/ex.themes.coms/',
'title' => 'Follow us on Facebook',
'icon'  => 'el el-facebook'
);
$args['share_icons'][] = array(
'url'   => 'https://twitter.com/ExThemes',
'title' => 'Follow us on Twitter',
'icon'  => 'el el-twitter'
);
$args['share_icons'][] = array(
'url'   => 'https://www.linkedin.com/in/bangreyblogs',
'title' => 'Find us on LinkedIn',
'icon'  => 'el el-linkedin'
);
$args['share_icons'][] = array(
'url'   => 'https://www.youtube.com/c/seomakassar',
'title' => 'Find us on Youtube',
'icon'  => 'el el-youtube'
);

$args['share_icons'][] = array(
'url'   => 'https://www.instagram.com/exthemescom/',
'title' => 'Find us on Instagram',
'icon'  => 'el el-instagram'
);

$args['share_icons'][] = array(
'url'   => 'https://exthem.es/',
'title' => 'Find us on Wordpress',
'icon'  => 'el el-wordpress'
);

// Panel Intro text -> before the form
if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
	if ( ! empty( $args['global_variable'] ) ) {
		$v = $args['global_variable'];
	} else {
		$v = str_replace( '-', '_', $args['opt_name'] );
	}
	//$args['intro_text'] = sprintf( __( '<noscript><p style="display:none">Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p></noscript>', 'moddroid' ), $v );
} else {
	//$args['intro_text'] = __( '<p style="display:none">This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'moddroid' );
}

// Add content after the form.
$args['footer_text'] = __( '<p></p>', 'moddroid' );

Redux::setArgs( $opt_name, $args );

// -> START extractor options
Redux::setSection( $opt_name, array(
'title'            => __( 'Extractor APK', 'moddroid' ),
'id'               => 'option_extractor_apk',
'customizer_width' => '500px',
'icon'             => 'el el-adjust-alt',
'fields'     => array(
 
			array(
			'id'       => 'aktif_thumbnails',
			'type'     => 'switch',
			'title'    => __( 'Thumbnails Google Play ', 'moddroid' ), 
			'desc'     => __('Click <code style="color: blue;">ON</code> to use <b style="color: blue;">Hotlink</b><br>Click <b style="color: red;">OFF</b> to use <b style="color: red;">Own images</b>','moddroid'),
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_extractor_apk_status_post_',
			'type'     => 'select',
			'title'    => __('Select for Status Post', 'moddroid'),
			'desc' => __('<i>Draft or Publish * <b>Publish</b> to auto post</i>', 'moddroid'),
			//'desc'     => __('<i>* Draft or Publish</i>', 'moddroid'),
			// Must provide key => value pairs for select options
			'options'  => array(
			'draft' => 'Draft',
			'publish' => 'Publish'
			),
			'default'  => 'draft',
			),
			array(
			'id'       => 'ex_themes_extractor_apk_title_',
			'type'     => 'select',
			'title'    => __('Select for Title Post', 'moddroid'),
			'desc' => __('<i>* Title Mods or Title App Name PlayStore</i>', 'moddroid'),
			//'desc'     => __('<i>* Title with Mods or Title from App Name</i>', 'moddroid'),
			// Must provide key => value pairs for select options
			'options'  => array(
			'title' => 'Title Mods',
			'title_GP' => 'Title PlayStore'
			),
			'default'  => 'title_GP',
			),
			array(
			'id'       => 'ex_themes_extractor_apk_permalink_',
			'type'     => 'select',
			'title'    => __('Select for Permalink Post', 'moddroid'),
			'desc' => __('<i>* Permalink Title with Mods or Permalink Title from App Name</i>', 'moddroid'),
			//'desc'     => __('<i>* Title with Mods or Title from App Name</i>', 'moddroid'),
			// Must provide key => value pairs for select options
			'options'  => array(
			'title' => 'Permalink Title with Mods',
			'title_GP' => 'Permalink Title App Name'
			),
			'default'  => 'title_GP',
			),
			/*
			array(
			'id'       => 'ex_themes_extractor_apk_debug_',
			'type'     => 'switch',
			'title'    => __( 'Showing Debugs', 'moddroid' ),
			'subtitle' => __('<i>for developer only *if you dont know leave it default OFF </i>', 'moddroid'),
			'default'  => false
			),
			*/


)
) );


// -> START Basic Fields __('Main settings')
Redux::setSection( $opt_name, array(
'title'            => __( 'General', 'moddroid' ),
'id'               => 'dashboard_ex_themes',
'customizer_width' => '700px',
'icon'             => 'el el-dashboard',
'subsection'       => false,
) );

Redux::setSection( $opt_name, array(
'title'            => __( 'Headers', 'moddroid' ),
'id'               => 'header',
'subsection'       => true,
'customizer_width' => '700px',
'icon'             => 'el el-wrench',
'fields'           => array(
			array(
			'id'       => 'ex_themes_header_logo_text_activate_',
			'type'     => 'switch',
			'title'    => 'Titles Header',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_header_logo_texts_',
			'type'     => 'text',
			'title'    => __( 'Title', 'moddroid' ),
			'default'  => 'Moddroid ',
			'required' => array( 'ex_themes_header_logo_text_activate_', '=', true )
			),

			array(
			'id'       => 'ex_themes_header_logo_banner_activate_',
			'type'     => 'switch',
			'title'    => 'Logo Banner',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_header_logo_banner_',
			'type'     => 'media',
			'title'    => __( 'Logo Banner', 'moddroid' ),
			'default'  => array(
			'url'=> ''.get_bloginfo('template_directory') . '/assets/img/logo.png'),
			'desc'     => __('Upload Your Logo Bannner','moddroid'),
			'required' => array( 'ex_themes_header_logo_banner_activate_', '=', true )
			),
			array(
			'id'       => 'ex_themes_header_favicon_activate_',
			'type'     => 'switch',
			'title'    => 'Favicons',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_header_favicons_',
			'type'     => 'media',
			'title'    => __( 'Favicons', 'moddroid' ),
			'default'  => array(
			'url'=> ''.get_bloginfo('template_directory') . '/assets/img/lazy.png'),
			'desc'     => __('Upload Your Favicons','moddroid'),
			'required' => array( 'ex_themes_header_favicon_activate_', '=', true )
			),
			array(
			'id'       => 'ex_themes_defaults_no_images_',
			'type'     => 'media',
			'title'    => __( 'Logo No Images Found', 'moddroid' ),
			'default'  => array(
			'url'=> ''.get_bloginfo('template_directory') . '/assets/img/lazy.png'),
			'desc'     => __('Upload Your Default No Images Found','moddroid') 
			),
)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Footers', 'moddroid' ),
'id'               => 'footers',
'customizer_width' => '500px',
'subsection'       => true,
'icon'             => 'el el-wrench',
'fields'     => array(
			array(
			'id'       => 'ex_themes_footers_activate_',
			'type'     => 'switch',
			'title'    => 'Analytics Code',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_footers_code_',
			'type'     => 'textarea',
			'title'    => __( 'HTML Allowed', 'moddroid' ),
			'desc' => __( 'Insert Your Code Analytics', 'moddroid' ),
			//'desc'     => __( 'This is the description field, again good for additional info.', 'moddroid' ),
			'default'  => '',
			'required' => array( 'ex_themes_footers_activate_', '=', true )
			),
			array(
			'id'       => 'ex_themes_footers_copyrights_active_',
			'type'     => 'switch',
			'title'    => __( 'Footer Copyright', 'moddroid' ),
			//'subtitle' => __( '<br> ', 'moddroid' ),
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_footers_copyrights_code_',
			'type'     => 'editor',
			'title'    => __( 'HTML Allowed', 'moddroid' ),
			'desc' => __( 'Footer Copyright', 'moddroid' ),
			'default'  => "<a href='".get_option('home')."'>".get_option('blogname')."</a> - © <script type=\"text/javascript\">var creditsyear = new Date();document.write(creditsyear.getFullYear());</script> All rights reserved - Developer by <a href=\"https://exthem.es\" title=\"premium wordpress themes - exthem.es\"><strong style=\"text-transform: capitalize;\">exthem.es</strong></a>",
			'required' => array( 'ex_themes_footers_copyrights_active_', '=', true )
			),
)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Colour Styles', 'moddroid' ),
'id'               => 'color_styles',
'customizer_width' => '700px',
'icon'             => 'el el-css',
'subsection'       => true,
'fields'     => array(
			array(
			'id'       => 'color',
			'type'     => 'color',
			'title'    => __('Colors Sites', 'moddroid'),
			'desc' => __('*default: <b style="color: #008080;">#008080</b>', 'moddroid'),
			'default'  => '#008080',
			'validate' => 'color',
			),
			)
			) );
Redux::setSection( $opt_name, array(
'title'            => __( 'Settings', 'moddroid' ),
'id'               => 'generals_ex_themes_2',
'customizer_width' => '700px',
'icon'             => 'el el-adjust-alt',
'subsection'       => false,
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Home Pages', 'moddroid' ),
'id'               => 'option_homepage',
'customizer_width' => '500px',
'subsection'       => true,
'icon'             => 'el el-home',
'fields'     => array(
/* 
			array(
			'id'       => 'limit_categorie_home',
			'type'     => 'slider',
			'title'    => __( 'How much to showing for Home', 'moddroid' ),
			"default"          => 12,
			"min"              => 2,
			"step"             => 1,
			"max"              => 100,
			'display_value'    => 'text'
			),
			 */
			array(
			'id'       => 'aktif_news',
			'type'     => 'switch',
			'title'    => 'Enable News in Home',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'title_news',
			'type'     => 'text',
			'title'    => __( 'Title News', 'moddroid' ),
			'default'  => 'Latest News',
			'required' => array( 'aktif_news', '=', true )
			),
			array(
			'id'       => 'title_news_2',
			'type'     => 'text',
			'title'    => __( 'Get Mores', 'moddroid' ),
			'default'  => 'Get Mores',
			'required' => array( 'aktif_news', '=', true )
			),
			/* 
			array(
			'id'       => 'aktif_categorie_opt_1',
			'type'     => 'switch',
			'title'    => 'Enable Categories Opt 1',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'categorie_opt_1',
			'type'     => 'select',
			'data'     => 'category',
			'title'    => __( 'Select Categories for Opt 1', 'moddroid'),
			'required' => array( 'aktif_categorie_opt_1', '=', true )
			),
			array(
			'id'       => 'title_categorie_opt_1',
			'type'     => 'text',
			'title'    => __( 'Title Opt 1', 'moddroid' ),
			'subtitle' => __( '', 'moddroid' ),
			'default'  => 'Title Opt 1',
			'required' => array( 'aktif_categorie_opt_1', '=', true )
			),
			array(
			'id'       => 'title_categorie_opt_1_2',
			'type'     => 'text',
			'title'    => __( 'Title Opt 2', 'moddroid' ),
			'subtitle' => __( '', 'moddroid' ),
			'default'  => 'Get More....',
			'required' => array( 'aktif_categorie_opt_1', '=', true )
			),
			array(
			'id'       => 'popular_categorie_opt_1',
			'type'     => 'text',
			'title'    => __('Categories Opt 1', 'moddroid'),
			//'subtitle' => __('This must be a URL for showing more link', 'moddroid'),
			//'validate' => 'url',
			'default'  => '#',
			'required' => array( 'aktif_categorie_opt_1', '=', true )
			),
			array(
			'id'       => 'aktif_categorie_opt_2',
			'type'     => 'switch',
			'title'    => 'Enable Categories Opt 2',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'categorie_opt_2',
			'type'     => 'select',
			'data'     => 'category',
			'title'    => __( 'Select Categories for Opt 2', 'moddroid'),
			'required' => array( 'aktif_categorie_opt_2', '=', true )
			),
			array(
			'id'       => 'title_categorie_opt_2',
			'type'     => 'text',
			'title'    => __( 'Title Opt 1', 'moddroid' ),
			//'subtitle' => __( '', 'moddroid' ),
			'default'  => 'Title Opt 1',
			'required' => array( 'aktif_categorie_opt_2', '=', true )
			),
			array(
			'id'       => 'title_categorie_opt_2_2',
			'type'     => 'text',
			'title'    => __( 'Title Opt 2', 'moddroid' ),
			//'subtitle' => __( '', 'moddroid' ),
			'default'  => 'Get More....',
			'required' => array( 'aktif_categorie_opt_2', '=', true )
			),
			array(
			'id'       => 'popular_categorie_opt_2',
			'type'     => 'text',
			'title'    => __('Categories Opt 2', 'moddroid'),
			//'subtitle' => __('This must be a URL for showing more link', 'moddroid'),
			//'validate' => 'url',
			'default'  => '#',
			'required' => array( 'aktif_categorie_opt_2', '=', true )
			),
			array(
			'id'       => 'aktif_categorie_opt_3',
			'type'     => 'switch',
			'title'    => 'Enable Categories Opt 3',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'categorie_opt_3',
			'type'     => 'select',
			'data'     => 'category',
			'title'    => __( 'Select Categories for Opt 3 ', 'moddroid'),
			'required' => array( 'aktif_categorie_opt_3', '=', true )
			),
			array(
			'id'       => 'title_categorie_opt_3',
			'type'     => 'text',
			'title'    => __( 'Title Opt 1', 'moddroid' ),
			//'subtitle' => __( '', 'moddroid' ),
			'default'  => 'Title Opt 1',
			'required' => array( 'aktif_categorie_opt_3', '=', true )
			),
			array(
			'id'       => 'title_categorie_opt_3_2',
			'type'     => 'text',
			'title'    => __( 'Title Opt 2', 'moddroid' ),
			//'subtitle' => __( '', 'moddroid' ),
			'default'  => 'Get More....',
			'required' => array( 'aktif_categorie_opt_3', '=', true )
			),
			array(
			'id'       => 'popular_categorie_opt_3',
			'type'     => 'text',
			'title'    => __('Categories Opt 3 ', 'moddroid'),
			'default'  => '#',
			'required' => array( 'aktif_categorie_opt_3', '=', true )
			),
 */

)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Single Post', 'moddroid' ),
'id'               => 'related_posts',
'customizer_width' => '500px',
'subsection'       => true,
'icon'             => 'el el-pencil-alt',
'fields'     => array(
			array(
			'id'       => 'aktif_related_post',
			'type'     => 'switch',
			'title'    => 'Show Related Post',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'title_related_post_1',
			'type'     => 'text',
			'title'    => __( 'Title Opt 1', 'moddroid' ),
			//'subtitle' => __( '', 'moddroid' ),
			'default'  => 'Recommended for You',
			'required' => array( 'aktif_related_post', '=', true )
			),
			array(
			'id'       => 'title_related_post_2',
			'type'     => 'text',
			'title'    => __( 'Title Opt 2', 'moddroid' ),
			//'subtitle' => __( '', 'moddroid' ),
			'default'  => 'You may also like ',
			'required' => array( 'aktif_related_post', '=', true )
			),
			array(
			'id'       => 'title_related_post_3',
			'type'     => 'text',
			'title'    => __( 'Title Opt 3', 'moddroid' ),
			//'subtitle' => __( '', 'moddroid' ),
			'default'  => 'More from ',
			'required' => array( 'aktif_related_post', '=', true )
			),
			array(
			'id'       => 'aktif_ex_themes_gallery_images_gpstore_',
			'type'     => 'switch',
			'title'    => __( 'Enable Gallery Image', 'moddroid' ),
			//'subtitle' => 'Click <code>On</code> to Show Poster Gallery Image.',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_rating_apk_activate_',
			'type'     => 'switch',
			'title'    => __( 'Enable Rating ', 'moddroid' ),
			//'subtitle' => 'Click <code>On</code> to Show Poster Gallery Image.',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_gallery_content_activate_',
			'type'     => 'switch',
			'title'    => __( 'Random Gallery on inside content', 'moddroid' ),
			//'subtitle' => __( '<br> ', 'moddroid' ),
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_gallery_content_paragraph_on_',
			'type'     => 'slider',
			'title'    => __( 'Showing on', 'moddroid' ),
			"default"          => 3,
			"min"              => 2,
			"step"             => 1,
			"max"              => 100,
			'display_value'    => 'text',

			'required' => array( 'ex_themes_gallery_content_activate_', '=', true )
			),
			array(
			'id'       => 'ex_themes_youtube_content_activate_',
			'type'     => 'switch',
			'title'    => __( 'Add Random Youtube on inside content', 'moddroid' ),
			//'subtitle' => __( '<br> ', 'moddroid' ),
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_youtube_content_paragraph_on_',

			'type'     => 'slider',
			'title'    => __( 'Showing on', 'moddroid' ),
			"default"          => 2,
			"min"              => 2,
			"step"             => 1,
			"max"              => 100,
			'display_value'    => 'text',
			'required' => array( 'ex_themes_youtube_content_activate_', '=', true )
			),
			array(
			'id'       => 'ex_themes_comments_activate_',
			'type'     => 'switch',
			'title'    => __( 'Enable Comments ', 'moddroid' ),
			//'subtitle' => 'Click <code>On</code> to Show Poster Gallery Image.',
			'default'  => false
			),


)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Popular Pages', 'moddroid' ),
'id'               => 'popular_pages',
'customizer_width' => '500px',
'subsection'       => true,
'icon'             => 'el el-pencil-alt',
'fields'     => array(
			array(
			'id'       => 'limit_categorie',

			'type'     => 'slider',
			'title'    => __( 'Showing on', 'moddroid' ),
			"default"          => 12,
			"min"              => 2,
			"step"             => 1,
			"max"              => 100,
			'display_value'    => 'text',
			),
			array(
			'id'       => 'aktif_categorie_apps',
			'type'     => 'switch',
			'title'    => 'Enable Categories Apps',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'categorie_tops_apps',
			'type'     => 'select',
			'data'     => 'category',
			'title'    => __('Select Categories for Apps Page', 'moddroid'),
			'required' => array( 'aktif_categorie_apps', '=', true )

			),
			array(
			'id'       => 'aktif_categorie_games',
			'type'     => 'switch',
			'title'    => 'Enable Categories Games',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'categorie_tops_games',
			'type'     => 'select',
			'data'     => 'category',
			'title'    => __( 'Select Categories for Games Page', 'moddroid'),
			'required' => array( 'aktif_categorie_games', '=', true )
			),
)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Sidebar Widgets', 'moddroid' ),
'id'               => 'categorie_sidebar',
'customizer_width' => '500px',
'subsection'       => true,
'icon'             => 'el el-tags',
'fields'     => array(
			array(
			'id'       => 'aktif_categorie_sidebar_1',
			'type'     => 'switch',
			'title'    => 'Categories sidebar Opt 1',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'categorie_sidebar_1',
			'type'     => 'textarea',
			'title'    => __( 'HTML Allowed', 'moddroid' ),
			'desc'		=> __( 'Categories Sidebar Opt 1', 'moddroid' ),
			'default'  => '<section class="mb-2">
					<h4 class="h5 font-weight-semibold mb-3">
						<a class="text-body border-bottom-2 border-secondary d-inline-block pb-1" href="#put_your_links_here">
							Games
						</a>
					</h4>
					<div class="row">
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Action">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/fps-150x150.png" alt="Action">
								<span class="text-truncate text-body" style="min-width: 0;">
									Action
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Adventure">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/traveler-150x150.png" alt="Adventure">
								<span class="text-truncate text-body" style="min-width: 0;">
									Adventure
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Arcade">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/arcade-150x150.png" alt="Arcade">
								<span class="text-truncate text-body" style="min-width: 0;">
									Arcade
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Board">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/board-game-150x150.png" alt="Board">
								<span class="text-truncate text-body" style="min-width: 0;">
									Board
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Card">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/poker-cards-150x150.png" alt="Card">
								<span class="text-truncate text-body" style="min-width: 0;">
									Card
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Casual">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/ghost-150x150.png" alt="Casual">
								<span class="text-truncate text-body" style="min-width: 0;">
									Casual
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Fighting">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/swords-150x150.png" alt="Fighting">
								<span class="text-truncate text-body" style="min-width: 0;">
									Fighting
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Gambling">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/slot-machine-150x150.png" alt="Gambling">
								<span class="text-truncate text-body" style="min-width: 0;">
									Gambling
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Logic">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/logical-thinking-150x150.png" alt="Logic">
								<span class="text-truncate text-body" style="min-width: 0;">
									Logic
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="MOBA">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/moba-150x150.png" alt="MOBA">
								<span class="text-truncate text-body" style="min-width: 0;">
									MOBA
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Music">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/music-note-150x150.png" alt="Music">
								<span class="text-truncate text-body" style="min-width: 0;">
									Music
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Puzzle">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/puzzle-150x150.png" alt="Puzzle">
								<span class="text-truncate text-body" style="min-width: 0;">
									Puzzle
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Racing">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/racing-car-150x150.png" alt="Racing">
								<span class="text-truncate text-body" style="min-width: 0;">
									Racing
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Role Playing">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/role-playing-game-150x150.png" alt="Role Playing">
								<span class="text-truncate text-body" style="min-width: 0;">
									Role Playing
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="RPG">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/swords-150x150.png" alt="RPG">
								<span class="text-truncate text-body" style="min-width: 0;">
									RPG
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Simulation">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/interactive-150x150.png" alt="Simulation">
								<span class="text-truncate text-body" style="min-width: 0;">
									Simulation
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Sports">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/basketball-150x150.png" alt="Sports">
								<span class="text-truncate text-body" style="min-width: 0;">
									Sports
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Strategy">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/self-defense-150x150.png" alt="Strategy">
								<span class="text-truncate text-body" style="min-width: 0;">
									Strategy
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Survival">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/parachute-150x150.png" alt="Survival">
			<span class="text-truncate text-body" style="min-width: 0;">
			Survival
			</span>
			</a>
			</div>
			</div>
			</section>


			',
			'required' => array( 'aktif_categorie_sidebar_1', '=', true )
			),

			array(
			'id'       => 'aktif_categorie_sidebar_2',
			'type'     => 'switch',
			'title'    => 'Categories sidebar Opt 2',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'categorie_sidebar_2',
			'type'     => 'textarea',
			'title'    => __( 'HTML Allowed', 'moddroid' ),
			'desc' => __( 'Categories Sidebar Opt 2', 'moddroid' ),
			'default'  => '<section class="mb-2">
					<h4 class="h5 font-weight-semibold mb-3">
						<a class="text-body border-bottom-2 border-secondary d-inline-block pb-1" href="#put_your_links_here">
							Apps
						</a>
					</h4>
					<div class="row">
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Art &amp; Design">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/paint-150x150.png" alt="Art &amp; Design">
								<span class="text-truncate text-body" style="min-width: 0;">
									Art &amp; Design
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Auto &amp; Vehicles">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/baby-car-150x150.png" alt="Auto &amp; Vehicles">
								<span class="text-truncate text-body" style="min-width: 0;">
									Auto &amp; Vehicles
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Books &amp; Reference">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/book.png" alt="Books &amp; Reference">
								<span class="text-truncate text-body" style="min-width: 0;">
									Books &amp; Reference
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Business">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/business.png" alt="Business">
								<span class="text-truncate text-body" style="min-width: 0;">
									Business
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Communication">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/communication-.png" alt="Communication">
								<span class="text-truncate text-body" style="min-width: 0;">
									Communication
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Education">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/edu.png" alt="Education">
								<span class="text-truncate text-body" style="min-width: 0;">
									Education
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Emulator">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/joystick-150x150.png" alt="Emulator">
								<span class="text-truncate text-body" style="min-width: 0;">
									Emulator
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Entertainment">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/cat_40.png" alt="Entertainment">
								<span class="text-truncate text-body" style="min-width: 0;">
									Entertainment
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Health">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/cat_50.png" alt="Health">
								<span class="text-truncate text-body" style="min-width: 0;">
									Health
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Lifestyle">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/life.png" alt="Lifestyle">
								<span class="text-truncate text-body" style="min-width: 0;">
									Lifestyle
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Maps &amp; Navigation">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/map.png" alt="Maps &amp; Navigation">
								<span class="text-truncate text-body" style="min-width: 0;">
									Maps &amp; Navigation
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Music - Audio">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/music.png" alt="Music - Audio">
								<span class="text-truncate text-body" style="min-width: 0;">
									Music - Audio
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="News &amp; Magazines">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/news.png" alt="News &amp; Magazines">
								<span class="text-truncate text-body" style="min-width: 0;">
									News &amp; Magazines
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Personalization">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/cat_25.png" alt="Personalization">
								<span class="text-truncate text-body" style="min-width: 0;">
									Personalization
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Photography">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/photo.png" alt="Photography">
								<span class="text-truncate text-body" style="min-width: 0;">
									Photography
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Productivity">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/productivity.png" alt="Productivity">
								<span class="text-truncate text-body" style="min-width: 0;">
									Productivity
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Social">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/fb.png" alt="Social">
								<span class="text-truncate text-body" style="min-width: 0;">
									Social
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="System">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/gear-1-150x150.png" alt="System">
								<span class="text-truncate text-body" style="min-width: 0;">
									System
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Tools">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/gear-150x150.png" alt="Tools">
								<span class="text-truncate text-body" style="min-width: 0;">
									Tools
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Travel &amp; Local">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/coin.png" alt="Travel &amp; Local">
								<span class="text-truncate text-body" style="min-width: 0;">
									Travel &amp; Local
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Video Players &amp; Editors">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/video.png" alt="Video Players &amp; Editors">
								<span class="text-truncate text-body" style="min-width: 0;">
									Video Players &amp; Editors
								</span>
							</a>
						</div>
						<div class="col-6 mb-3">
							<a class="d-flex align-items-center position-relative aside-cat" href="#put_your_links_here" title="Weather">
								<img class="rounded-circle flex-shrink-0 mr-2" style="font-size: 0; width: 2rem; height: 2rem;" loading="lazy" src="'.get_bloginfo('template_directory').'/assets/img/icon/weather.png" alt="Weather">
			<span class="text-truncate text-body" style="min-width: 0;">
			Weather
			</span>
			</a>
			</div>
			</div>
			</section>

			',
			'required' => array( 'aktif_categorie_sidebar_2', '=', true )
			),


)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Download Notice & Info', 'moddroid' ),
'id'               => 'downloadss_posts',
'customizer_width' => '500px',
'subsection'       => true,
'icon'             => 'el el-info-circle',
'fields'     => array(


			array(
			'id'       => 'activate_download_faqs',
			'type'     => 'switch',
			'title'    => 'Enable FAQ Download',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'title_faq_1_',
			'type'     => 'text',
			'title'    => __( 'Title FAQ 1', 'moddroid' ),
			'default'  => 'What is APK Installer?',
			'required' => array( 'activate_download_faqs', '=', true )
			),
			array(
			'id'       => 'faq_1_',
			'type'     => 'editor',
			'title'    => __( ' ', 'moddroid' ),
			'desc' => __( 'HTML Allowed', 'moddroid' ),
			'default'  => "<p>This is an installer developed exclusively by <strong><em>".get_option('home')."</em> </strong>. We attach the Cache, OBB file to the single APK file, which helps users to install it quickly and easily.</p>",
			'required' => array( 'activate_download_faqs', '=', true )
			),
			array(
			'id'       => 'title_faq_2_',
			'type'     => 'text',
			'title'    => __( 'Title FAQ 2', 'moddroid' ),
			'default'  => 'The download link is broken!',
			'required' => array( 'activate_download_faqs', '=', true )
			),
			array(
			'id'       => 'faq_2_',
			'type'     => 'editor',
			'title'    => __( ' ', 'moddroid' ),
			'desc' => __( 'HTML Allowed', 'moddroid' ),
			'default'  => "<p><em>Since we use caching and the server has special sync functionality, sometimes some newly posted games will have broken links for a few minutes. You can try again in about 5-15 minutes. If after a long time the download link still fails, this is definitely a mistake in the editor’s link import process (possibly because he is sleepy)</em></p>",
			'required' => array( 'activate_download_faqs', '=', true )
			),
			array(
			'id'       => 'title_faq_3_',
			'type'     => 'text',
			'title'    => __( 'Title FAQ 3', 'moddroid' ),
			'default'  => 'MOD Not Working',
			'required' => array( 'activate_download_faqs', '=', true )
			),
			array(
			'id'       => 'faq_3_',
			'type'     => 'editor',
			'title'    => __( ' ', 'moddroid' ),
			'desc' => __( 'HTML Allowed', 'moddroid' ),
			'default'  => "<p><em>We always do thorough testing before posting games and apps. Please read carefully before the instructions that include “MOD Info?” “Important!” in the content. If it still doesn’t work, report it back to us</em></p>",
			'required' => array( 'activate_download_faqs', '=', true )
			),

			array(
			'id'       => 'title_faq_4_',
			'type'     => 'text',
			'title'    => __( 'Title FAQ 4', 'moddroid' ),
			'default'  => 'What is OBB? How to install?',
			'required' => array( 'activate_download_faqs', '=', true )
			),
			array(
			'id'       => 'faq_4_',
			'type'     => 'editor',
			'title'    => __( ' ', 'moddroid' ),
			'desc' => __( 'HTML Allowed', 'moddroid' ),
			'default'  => "<p><em>OBB is like the game’s DLC, you just need to unzip it to the “Android / obb” folder in the memory. The game will work properly. We rarely post an OBB, however, as it is already integrated into the INSTALLER APK as we mentioned earlier.</em></p>
			<p><em><strong>How to install game have APK and OBB</strong></em></p>
			<p><em>1. Download apk and OBB of the game</em><br>
			<em>2. Extract the OBB, copy the OBB folder to the “Android/obb” path. A correct OBB path would look like “Android/obb/com.madfingergames.legends”</em><br>
			<em>3. Install APK file and run</em></p>",
			'required' => array( 'activate_download_faqs', '=', true )
			),


			array(
			'id'       => 'title_faq_5_',
			'type'     => 'text',
			'title'    => __( 'Title FAQ 5', 'moddroid' ),
			'default'  => 'Error "App not installed"',
			'required' => array( 'activate_download_faqs', '=', true )
			),
			array(
			'id'       => 'faq_5_',
			'type'     => 'editor',
			'title'    => __( ' ', 'moddroid' ),
			'desc' => __( 'HTML Allowed', 'moddroid' ),
			'default'  => "<p><em>This usually happens when you already have the original version or version downloaded on another website on your device. To fix it, please delete the app or game (remember to backup data if necessary), then reinstall our apk file</em></p>",
			'required' => array( 'activate_download_faqs', '=', true )
			),




			array(
			'id'       => 'activate_download_notices',
			'type'     => 'switch',
			'title'    => 'Enable Notices Download',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'notice_download_pages',
			'type'     => 'editor',
			'title'    => __( 'Notices for Download Pages', 'moddroid' ),
			'desc' => __( 'HTML Allowed', 'moddroid' ),
			'default'  => "<ul>
								<li>Please check our installation guide.</li>
								<li>To check the CPU and GPU of Android device, please use <em><a href=\"https://play.google.com/store/apps/details?id=com.cpuid.cpu_z&amp;hl=en\">CPU-Z</a></em> app</li>
							</ul>",
			'required' => array( 'activate_download_notices', '=', true )
			),

			array(
			'id'       => 'ex_themes_banner_ads_fake_activate_',
			'type'     => 'switch',
			'title'    => 'Fake Download',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_ads_fake_title_',
			'type'     => 'text',
			'title'    => __( 'Title Fake Download', 'moddroid' ),
			'desc' => __( 'Fake Name Title', 'moddroid' ),
			'default'  => 'Fast Download APK MOD & OBB File',
			'required' => array( 'ex_themes_banner_ads_fake_activate_', '=', true )
			),
			array(
			'id'       => 'ex_themes_banner_ads_fake_url_',
			'type'     => 'text',
			'title'    => __( 'Link URL Fake Download', 'moddroid' ),
			'desc' => __( 'Fake Download Link.', 'moddroid' ),
			'validate' => 'url',
			'default'  => 'https://exthem.es',
			'required' => array( 'ex_themes_banner_ads_fake_activate_', '=', true )
			),
			
			
			array(
			'id'       => 'safelink_timers_',

			'type'     => 'slider',
			'title'    => __( 'Timer Counts', 'moddroid' ),
			"default"          => 3,
			"min"              => 2,
			"step"             => 1,
			"max"              => 60,
			'display_value'    => 'text',
			/* 'required' => array( 'activate_safelink_pages', '=', true ) */
			),
			
			/* array(
			'id'       => 'ex_themes_banner_ads_fake_timer_activate_',
			'type'     => 'switch',
			'title'    => 'Timer Counts Manages',
			//'desc' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_ads_fake_timers_',

			'type'     => 'slider',
			'title'    => __( 'Timer Counts', 'moddroid' ),
			"default"          => 3,
			"min"              => 2,
			"step"             => 1,
			"max"              => 60,
			'display_value'    => 'text',
			'desc' => 'Choices Your Time',
			'required' => array( 'ex_themes_banner_ads_fake_timer_activate_', '=', true )
			),
			 */
)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Advertise', 'moddroid' ),
'id'               => 'ads',
'customizer_width' => '500px',
'icon'             => 'el el-usd',
'fields'     => array(
			array(
			'id'       => 'ex_themes_banner_header_activate_',
			'type'     => 'switch',
			'title'    => 'Ads in Home, Archive, Category, 404, Search',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_header_code_',
			'type'     => 'textarea',
			'title'    => '&nbsp;',
			'desc' => '<i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'ex_themes_banner_header_activate_', '=', true )
			),
			array(
			'id'       => 'ex_themes_banner_sidebar_ads_activate_',
			'type'     => 'switch',
			'title'    => 'Ads in Sidebar',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_sidebar_ads_code_',
			'type'     => 'textarea',
			'title'    => '&nbsp;',
			'desc' => '<i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'ex_themes_banner_sidebar_ads_activate_', '=', true )
			),

			array(
			'id'       => 'ex_themes_banner_single_ads_activate_',
			'type'     => 'switch',
			'title'    => 'Ads Single Top',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_single_ads_code_',
			'type'     => 'textarea',
			'title'    => '&nbsp;',
			'desc' => '<i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'ex_themes_banner_single_ads_activate_', '=', true )
			),
			array(
			'id'       => 'ex_themes_banner_single_ads_activate_2',
			'type'     => 'switch',
			'title'    => 'Ads Single Bottom',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_single_ads_code_2',
			'type'     => 'textarea',
			'title'    => '&nbsp;',
			'desc' => '<i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'ex_themes_banner_single_ads_activate_2', '=', true )
			),
			array(
			'id'       => 'ex_themes_banner_single_download_page_active_',
			'type'     => 'switch',
			'title'    => 'Ads Page Download',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_single_download_page_code_',
			'type'     => 'textarea',
			'title'    => '&nbsp;',
			'desc' => '<i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'ex_themes_banner_single_download_page_active_', '=', true )
			),
			array(
			'id'       => 'ex_themes_banner_single_download_page_active__2',
			'type'     => 'switch',
			'title'    => 'Ads 2 in Single Download',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_single_download_page_code__2',
			'type'     => 'textarea',
			'title'    => '&nbsp;',
			'subtitle' => '<i>*Insert Your Code HTML.</i>',
			'default'  => "<img src=\"".get_bloginfo('template_directory') . "/assets/img/ads1.png\" height=\"auto\" width=\"100%\">",
			'required' => array( 'ex_themes_banner_single_download_page_active__2', '=', true )
			),/*
			array(
			'id'       => 'ex_themes_banner_single_download_page_active__3',
			'type'     => 'switch',
			'title'    => 'ADS Single Download 3',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_single_download_page_code__3',
			'type'     => 'textarea',
			'title'    => '&nbsp;',
			'subtitle' => '<i>*Insert Your Code HTML.</i>',
			'default'  => "<img src=\"".get_bloginfo('template_directory') . "/assets/img/ads1.png\" height=\"auto\" width=\"100%\">",
			'required' => array( 'ex_themes_banner_single_download_page_active__3', '=', true )
			),
			*/
			/*
			array(
			'id'       => 'ex_themes_banner_single_download_page_ads_activate_',
			'type'     => 'switch',
			'title'    => 'ADS Download Page',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_banner_single_download_page_ads_code_',
			'type'     => 'textarea',
			'title'    => '&nbsp;',
			'subtitle' => '<i>*Insert Your Code HTML.</i>',
			'required' => array( 'ex_themes_banner_single_download_page_ads_activate_', '=', true )
			),
			*/
)
) );
// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Webmasters', 'moddroid' ),
'id'               => 'webmaster_tools_verification',
'customizer_width' => '500px',
'icon'             => 'el el-globe',
'fields'     => array(
			array(
			'id'       => 'aktif_webmaster',
			'type'     => 'switch',
			'title'    => 'Enable Webmasters Verification',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),

			array(
			'id'       => 'google_verif',
			'type'     => 'text',
			'title'    => __( 'Google Search Console', 'moddroid' ),
			'subtitle' => __( 'Insert Code Google Search Console ', 'moddroid' ),
			'default'  => 'AvKGNc41mcT7TmHke8nHR5U99NHLk2-eJw_j6PyQq94',
			'required' => array( 'aktif_webmaster', '=', true )
			),
			array(
			'id'       => 'bing_verif',
			'type'     => 'text',
			'title'    => __( 'Bing Webmaster Tools', 'moddroid' ),
			'subtitle' => __( 'Insert Code Bing Webmaster Tools', 'moddroid' ),
			'default'  => 'BC97A518A2B909C0B1A76AD695E9A665',
			'required' => array( 'aktif_webmaster', '=', true )
			),
			array(
			'id'       => 'pinterest_verif',
			'type'     => 'text',
			'title'    => __( 'Pinterest Site Verification', 'moddroid' ),
			'subtitle' => __( 'Insert Code Pinterest Site Verification', 'moddroid' ),
			'default'  => 'put your code',
			'required' => array( 'aktif_webmaster', '=', true )
			),
			array(
			'id'       => 'yandex_verif',
			'type'     => 'text',
			'title'    => __( 'Yandex Webmaster Tools', 'moddroid' ),
			'subtitle' => __( 'Insert Code Yandex Webmaster Tools', 'moddroid' ),
			'default'  => 'bb0b65aedc95ce07',
			'required' => array( 'aktif_webmaster', '=', true )
			),
			array(
			'id'       => 'baidu_verif',
			'type'     => 'text',
			'title'    => __( 'Baidu Webmaster Tools', 'moddroid' ),
			'subtitle' => __( 'Insert Code Baidu Webmaster Tools ', 'moddroid' ),
			'default'  => 'put your code',
			'required' => array( 'aktif_webmaster', '=', true )
			),


)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Social Media', 'moddroid' ),
'id'               => 'sosial_media',
'customizer_width' => '500px',
'icon'             => 'el el-facebook',
'fields'     => array(
			array(
			'id'       => 'aktif_sosmed_sidebar',
			'type'     => 'switch',
			'title'    => 'Social Links Accounts',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),

			array(
			'id'       => 'facebook_url',
			'type'     => 'text',
			'title'    => __( 'Facebook', 'moddroid' ),
			//'subtitle' => __( 'This must be a URL.', 'moddroid' ),
			'validate' => 'url',
			'default'  => 'https://web.facebook.com/ex.themescom',
			'required' => array( 'aktif_sosmed_sidebar', '=', true )
			),

			array(
			'id'       => 'twitter_url',
			'type'     => 'text',
			'title'    => __( 'Twitter', 'moddroid' ),
			//'subtitle' => __( 'This must be a URL.', 'moddroid' ),
			'validate' => 'url',
			'default'  => 'https://twitter.com/ExThemes',
			'required' => array( 'aktif_sosmed_sidebar', '=', true )
			),

			array(
			'id'       => 'youtube_url',
			'type'     => 'text',
			'title'    => __( 'Youtube', 'moddroid' ),
			//'subtitle' => __( 'This must be a URL.', 'moddroid' ),
			'validate' => 'url',
			'default'  => 'https://www.youtube.com/c/seomakassar',
			'required' => array( 'aktif_sosmed_sidebar', '=', true )
			),

			array(
			'id'       => 'instagram_url',
			'type'     => 'text',
			'title'    => __( 'Instagram', 'moddroid' ),
			//'subtitle' => __( 'This must be a URL.', 'moddroid' ),
			'validate' => 'url',
			'default'  => 'https://www.instagram.com/exthemescom/',
			'required' => array( 'aktif_sosmed_sidebar', '=', true )
			),

			array(
			'id'       => 'telegram_url',
			'type'     => 'text',
			'title'    => __( 'Telegram', 'moddroid' ),
			//'subtitle' => __( 'This must be a URL.', 'moddroid' ),
			'validate' => 'url',
			'default'  => 'https://telegram.me/apkdone1',
			'required' => array( 'aktif_sosmed_sidebar', '=', true )
			),

			array(
			'id'       => 'telegram_users',
			'type'     => 'text',
			'title'    => __( 'Telegram User', 'moddroid' ),
			//'subtitle' => __( 'This must be a URL.', 'moddroid' ),
			/* 'validate' => 'url', */
			'default'  => 'apkdone1',
			'required' => array( 'aktif_sosmed_sidebar', '=', true )
			),

			array(
			'id'       => 'pinterest_url',
			'type'     => 'text',
			'title'    => __( 'Pinterest', 'moddroid' ),
			//'subtitle' => __( 'This must be a URL.', 'moddroid' ),
			'validate' => 'url',
			'default'  => 'https://pinterest.com/exthemes',
			'required' => array( 'aktif_sosmed_sidebar', '=', true )
			),

			array(
			'id'       => 'linked_url',
			'type'     => 'text',
			'title'    => __( 'Linkedin', 'moddroid' ),
			//'subtitle' => __( 'This must be a URL.', 'moddroid' ),
			'validate' => 'url',
			'default'  => 'https://www.linkedin.com/in/bangreyblogs',
			'required' => array( 'aktif_sosmed_sidebar', '=', true )
			),

			array(
			'id'       => 'VKontakte_url',
			'type'     => 'text',
			'title'    => __( 'VKontakte ', 'moddroid' ),
			//'subtitle' => __( 'This must be a URL.', 'moddroid' ),
			'validate' => 'url',
			'default'  => 'https://vk.com/jadwal_21',
			'required' => array( 'aktif_sosmed_sidebar', '=', true )
			),



)
) );


// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Safelink Pages', 'moddroid' ),
'id'               => 'safelink_pages',
'customizer_width' => '500px',
'subsection'       => false,
'icon'             => 'el el-pencil-alt',
'fields'     => array(

			array(
			'id'       => 'activate_safelink_pages',
			'type'     => 'switch',
			'title'    => 'Enable Safelink',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),

			array(
				'id'    => 'info_options_safelink',
				'type'  => 'info',
				'title' => __('How To Use Safelink Pages', 'moddroid'),
				'style' => 'critical',
				'desc'  => __('<ol>
				<li>Make New Pages or <a href="/wp-admin/post-new.php?post_type=page" target="_blank" style="text-transform: uppercase;color: #2271b1;">click here</a> ,</li>
<li>Put Title Whats You Wants Use. Example... im use "<b style="text-transform: uppercase;color: #2271b1;">go</b>"</li>
<li>Cick "<b style="text-transform: uppercase;color: #2271b1;">EDIT</b>" on Permalink. Put "<b style="text-transform: uppercase;color: #2271b1;">Go</b>" or "<b style="text-transform: uppercase;color: #2271b1;">Whats You Wants</b>".  Example... im use "<b style="text-transform: uppercase;color: #2271b1;">go</b>"</li>
<li>Change Template to "<b style="text-transform: uppercase;color: #2271b1;">Template Safelink 2</b>"</li>
<li>Click "<b style="text-transform: uppercase;color: #2271b1;">Publish</b>" Now</li>
<li>Now You "<b style="text-transform: uppercase;color: #2271b1;">Got Safelink Page</b>" likes "<b style="text-transform: uppercase;color: #2271b1;">'.get_option('home').'/go</b>"</li>
</ol>
<b style="color: red;">PLEASE NOTE:</b> <br>Look on Images if you dont understand</b>
<br>
<br>
<img src="'.get_bloginfo('template_directory') . '/assets/img/safelink_pages.png"><br>
<br> ', 'moddroid'),
				'required' => array( 'activate_safelink_pages', '=', true ),

			), 
        


			array(
			'id'       => 'safelink_protect_links',
			'type'     => 'text',
			'title'    => 'UnProtect Website Link Domains',
			'desc' => '<b style="text-transform: uppercase;color: #2271b1;">separate with comma</b> <br> <i style="text-transform: lowercase;color: #2271b1;">example : mydomain.com, mysites.com, facebook.com, twitter.com, telegram.com</i>',
			'default'  => "".get_option('home')." , facebook.com, twitter.com, telegram.com, ",
			'required' => array( 'activate_safelink_pages', '=', true )
			),
			array(
			'id'       => 'safelink_url_pages',
			'type'     => 'text',
			'title'    => 'URL Link Pages Safelink',
			'desc' => "<b style=\"text-transform: capitalize;color: #2271b1;\">Use You Safelink Page Link...</b> <i style=\"text-transform: lowercase;color: #2271b1;\">example : ".get_option('home')."/go</i>",
			'default'  => "".get_option('home')."/go",
			'required' => array( 'activate_safelink_pages', '=', true )
			),
			
			array(
			'id'       => 'activate_safelink_banner_',
			'type'     => 'switch',
			'title'    => 'Ads for Safelink Pages',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'desc' => '<b style="text-transform: uppercase;color: #2271b1;">*Only Work for Template Safelink 1</b>',
			'default'  => false
			),
			array(
			'id'       => 'articles_safelink_pages',
			'type'     => 'editor',
			'title'    => __( 'HTML Allowed', 'moddroid' ),
			'desc' => __( '<b style="color: blue;">*Only Work for Template Safelink 1</b> <br>Add or Edit Articles for Safelink ', 'moddroid' ),
			'default'  => "<p><a >Netcapsule VPN</a> is among the leading VPNs in Google Play Store and it is 100% safe and also has lightning speed. If you are looking for a VPN that is super easy to use, safe and fast then Netcapsule VPN is the VPN to go for. The VPN lets you browse the internet anonymously and privately. Browsing anonymously and safely on the internet is not the only thing that Netcapsule will help you to do. We will share more on what we have learned considering Netcapsule VPN.</p>
						   <h2><span>Why do I need Netcapsule VPN?</span></h2>
						   <p>As the world of technology is advancing each day, you also need to keep advancing. Virtual private networks have become so important that surfing the internet without them is a huge risk to your online endeavors. So you need Netcapsule VPN for the following reasons;</p>
						   <p><strong>1. Unblock restricted sites</strong></p>
						   <p>Has your government banned some apps that you would want to use? Well, with Netcapsule VPN you can unblock these apps or sites and you can use them safely and anonymously. In addition, you can bypass any government restrictions and be able to access any content you want on the internet safely and privately.</p>
						   <p>You can also unblock any app or game that you want to use on the internet. If you are blocked from accessing some movies, shows, or music you can use netcapsule to unblock and use them as you like.</p>
						   <p><strong>2. Privacy</strong></p>
						   <p>Your ISP may be tracking your moves online or you may have noticed that someone is trying to follow your every move online. If this is you, then you need to make good use of the Netcapsule VPN to surf privately. Netcapsule VPN for PC lets you surf the internet without anyone knowing your every move online.</p>
						   <p>Netcapsule will never keep your online information so you are guaranteed your safety and privacy online. With this in mind, you can safely visit any site you wish privately.</p>
						   <p><strong>3. Hide your real IP</strong></p>
						   <p>Sometimes it would help if your real IP is hidden while you browse the internet. Some sites prohibit some IPs from accessing their information but you shouldn’t be on the losing end If You Use Netcapsule VPN. The VPN allows you to mask your real IP address and you can put up any IP address you want as you browse. You can hide your real IP and mask it with any IP address that you want and no one will notice it.</p>
						   <p><strong>4. Hotspot shield</strong></p>
						   <p>Do you know some people will still use your Wi-Fi connection even if you haven’t given them your password? Well, if you did not know it now you know. To avoid this Netcapsule VPN helps you mask your connection so that no one else can use it. It is advisable to use such a VPN that helps you protect your connection especially if you are using your Wi-Fi in public. Additionally, the VPN helps you to stay safe especially if you are using public Wi-Fi to avoid scammers and hackers accessing any of your information online.</p>
						   <h2><span>Advantages of Netcapsule VPN</span></h2>
						   Here, we will share with you some of the best features that are related to Netcapsule VPN for PC;
						   <ul>
							  <li>It has a very easy-to-use interface.</li>
							  <li>Most VPNs will ask for your personal details for you to sign up and use them but Netcapsule does not require any of your personal details.</li>
							  <li>Netcapsule VPN will immediately hide your online activities and IP address after connecting to it.</li>
							  <li>The VPN attained the one million mark of installations a few days after it was officially launched.</li>
							  <li>It is completely free to use.</li>
							  <li>You can connect to up to 40/50 different countries.</li>
							  <li>You can download the app on Android, Mac, iPhone, and Windows devices. (for PC devices you need a separate method, read on to find it)</li>
						   </ul>
						   <h2><span>People Also Asked</span></h2>
						   <p><strong>1. Is Netcapsule for PC free download available for Windows?</strong></p>
						   <p>Yes, you can install Netcapsule VPN on your Windows devices but you have to use an Android emulator. Follow the instructions below to download Netcapsule VPN for PC;</p>
						   <ul>
							  <li>Install Bluestacks from their official website. Here is the official website of Bluestacks <strong>https://www.bluestacks.com/</strong>.</li>
							  <li>Follow the instructions to complete the downloading and installation process.</li>
							  <li>Now you need to enter your Gmail information to access the Google play store.</li>
							  <li>Search for Netcapsule VPN and click on the install button.</li>
							  <li>After you install the VPN, you can enjoy surfing the internet free, safely, and privately.</li>
						   </ul>
						   <p>
							  <strong>2. Is Netcapsule VPN for PC free?</strong>
						   </p>
						   <p>Yes, Netcapsule is free to use whether on your PC or on your Android or iPhone device. The VPN is 100% free to use. You do not have to pay for anything while installing the VPN on your mobile phone or on your PC.</p>
						   <p> <strong>3. Is Netcapsule VPN safe to use?</strong></p>
						   <p>First, this VPN does not require any of your personal details to connect to it which means that your information is safe with you. Apart from this one reason, the VPN also hides your IP and your online details once you are connected to it. It is therefore safe to say that Netcapsule is safe to use</p>
						   <p><strong>4. Do I need to use Netcapsule APK?</strong></p>
						   <p>Well, if you will be using BlueStacks to download the app on your PC then you do not need Netcapsule APK to download it on your PC. However, if you will be using the <strong>Memu emulator</strong> to download and install the app on your PC then you will need Netcapsule APK to download the app on your PC. Memu requires an APK for you to download any Android app on your PC.</p>
						   <h2><span>Opinion</span></h2>
						   <p>If you are going to look deep into your budget before considering a VPN then you need to be careful about the VPN you choose. Most free VPNs are not genuine but Netcapsule VPN is one of the few VPNs one can get from the VPNs market. So you can give it a trial and see how far you can go with it.</p>",
			'required' => array( 'activate_safelink_banner_', '=', true )
			),

			array(
			'id'       => 'safelink_banner_billboard',
			'type'     => 'textarea',
			'title'    => 'Banner Ads for billboard',
			'desc' => '<b style="color: blue;">*Only Work for Template Safelink 1</b><br><i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'activate_safelink_banner_', '=', true )
			),

			array(
			'id'       => 'safelink_banner_300_1',
			'type'     => 'textarea',
			'title'    => 'Banner Ads for 300 left',
			'desc' => '<b style="color: blue;">*Only Work for Template Safelink 1</b><br><i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'activate_safelink_banner_', '=', true )
			),

			array(
			'id'       => 'safelink_banner_300_2',
			'type'     => 'textarea',
			'title'    => 'Banner Ads for 300 right',
			'desc' => '<b style="color: blue;">*Only Work for Template Safelink 1</b><br><i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'activate_safelink_banner_', '=', true )
			),


			array(
			'id'       => 'safelink_banner_234',
			'type'     => 'textarea',
			'title'    => 'Banner Ads for below download button',
			'desc' => '<b style="color: blue;">*Only Work for Template Safelink 1</b><br><i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'activate_safelink_banner_', '=', true )
			),

			array(
			'id'       => 'safelink_banner_970',
			'type'     => 'textarea',
			'title'    => 'Banner Ads for footer',
			'desc' => '<b style="color: blue;">*Only Work for Template Safelink 1</b><br><i>*Insert Your Code HTML.</i>',
			'default'  => "<div class=\"ads-here\"><i class=\"ads-img\"></i><i class=\"ads-content\"></i><i class=\"ads-button\"></i></div>",
			'required' => array( 'activate_safelink_banner_', '=', true )
			),

)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Inject Script or CSS', 'moddroid' ),
'id'               => 'script_insert',
'customizer_width' => '500px',
'icon'             => 'el el-pencil',

'fields'     => array(
			array(
			'id'       => 'aktif_header_section',
			'type'     => 'switch',
			'title'    => 'Header Sections',
			//'subtitle' => 'Click <code>On</code> to Activate.',
			'default'  => false
			),
			array(
			'id'       => 'header_section',
			'type'     => 'textarea',
			'title'    => __( 'HTML Allowed', 'moddroid' ),
			'desc' => __( 'You can Inject Scripts or CSS Style on Header', 'moddroid' ),
			'required' => array( 'aktif_header_section', '=', true )

			),
			array(
			'id'       => 'aktif_footer_section',
			'type'     => 'switch',
			'title'    => 'Footer Sections',
			//'subtitle' => 'Click <code>On</code> to Activate.',
			'default'  => false
			),
			array(
			'id'       => 'footer_section',
			'type'     => 'textarea',
			'title'    => __( 'HTML Allowed', 'moddroid' ),
			'desc' => __( 'You can Inject Scripts or CSS Style on Footer', 'moddroid' ),
			'required' => array( 'aktif_footer_section', '=', true )

			),

)
) );

// -> START Editors
Redux::setSection( $opt_name, array(
'title'            => __( 'Options', 'moddroid' ),
'id'               => 'optionz',
'customizer_width' => '500px',
'icon'             => 'el el-wrench',

'fields'     => array(

			/*
			array(
			'id'       => 'aktif_fake_views',
			'type'     => 'switch',
			'title'    => 'Activate Fake Views',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),
			*/

			/**/

			array(
			'id'       => 'ex_themes_classic_editor_activate_',
			'type'     => 'switch',
			'title'    => __( 'Editor Classic ', 'moddroid' ),
			//'subtitle' => __( '<br> ', 'moddroid' ),
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_minify_activate_',
			'type'     => 'switch',
			'title'    => 'Minify Sites',
			//'subtitle' => 'Click <code>On</code> to Activate',
			'default'  => false
			),

			array(
			'id'       => 'ex_themes_remove_version_scripts_styles_activate_',
			'type'     => 'switch',
			'title'    => __( 'Remove Version Scripts Styles', 'moddroid' ),
			//'subtitle' => __( '<br> ', 'moddroid' ),
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_disable_emojis_activate_',
			'type'     => 'switch',
			'title'    => __( 'Remove Emojis Script', 'moddroid' ),
			//'subtitle' => __( '<br> ', 'moddroid' ),
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_add_img_title_activate_',
			'type'     => 'switch',
			'title'    => __( 'Automatic Image Title Tag', 'moddroid' ),
			//'subtitle' => __( '<br> ', 'moddroid' ),
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_async_scripts_activate_',
			'type'     => 'switch',
			'title'    => __( 'Defer & Async Attributes', 'moddroid' ),
			//'subtitle' => __( '<br> ', 'moddroid' ),
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_bar_admin_activate_',
			'type'     => 'switch',
			'title'    => 'Hide Bar Admin',
			//'subtitle' => 'Click <code>On</code> to Activate.',
			'default'  => false
			),			
			array(
			'id'       => 'ex_themes_mask_link_',
			'type'     => 'switch',
			'title'    => 'Masking Link',
			'desc' => '*<i>Masking your Download Link</i>',
			'default'  => false
			),
			array(
			'id'       => 'ex_themes_activate_seox',
			'type'     => 'switch',
			'title'    => 'SEO Schema',
			'desc' => 'Click <code style="text-transform: uppercase;color: #2271b1;">On</code> to use automatic <code style="text-transform: uppercase;color: #2271b1;">seo scheme</code><br>if you <code style="text-transform: uppercase;color: #2271b1;">OFF</code> you have to use plugin SEO',
			'default'  => false
			),	
			array(
			'id'       => 'ex_themes_activate_rtl_',
			'type'     => 'switch',
			'title'    => 'RTL Modes',
			'desc' => '*Click <code>On</code> to Use RTL',
			'default'  => false
			),






)
) );

Redux::setSection( $opt_name, array(
'title'            => __( 'Change Language', 'moddroid' ),
'id'               => 'translate_options',
'customizer_width' => '500px',
'icon'             => 'el el-adjust-alt',
'fields'     => array(

			array(
			'id'    => 'info_translate_options',
			'type'  => 'info',
			'title' => __('THIS IS INFO FOR CHANGE LANGUAGE AS YOU WISH', 'moddroid'),
			'style' => 'critical',
			'desc'  => __('', 'moddroid')
			),
			
			array(
			'id'       => 'title_home',
			'type'     => 'text',
			'title'    => __( 'Latest Updates', 'moddroid' ),
			'default'  => 'Latest Updates'
			),
			array(
			'id'       => 'exthemes_Search',
			'type'     => 'text',
			'title'    => __( 'Search', 'moddroid' ),
			'default'  => 'Search',
			),
			array(
			'id'       => 'exthemes_Searchresults',
			'type'     => 'text',
			'title'    => __( 'Search results for:', 'moddroid' ),
			'default'  => 'Search results for:',
			),
			array(
			'id'       => 'exthemes_File_not_founds',
			'type'     => 'text',
			'title'    => __( 'File not founds or File has been remove', 'moddroid' ),
			'default'  => 'File not founds or File has been remove',
			),
			array(
			'id'       => 'exthemes_News',
			'type'     => 'text',
			'title'    => __( 'News', 'moddroid' ),
			'default'  => 'News',
			),
			array(
			'id'       => 'exthemes_Comments',
			'type'     => 'text',
			'title'    => __( 'Comments', 'moddroid' ),
			'default'  => 'Comments',
			),
			array(
			'id'       => 'exthemes_Download',
			'type'     => 'text',
			'title'    => __( 'Download', 'moddroid' ),
			'default'  => 'Download',
			),
			array(
			'id'       => 'exthemes_toc',
			'type'     => 'text',
			'title'    => __( 'Table of Content', 'moddroid' ),
			'default'  => 'Explore this article',
			),
			array(
			'id'       => 'exthemes_NameAPK',
			'type'     => 'text',
			'title'    => __( 'Name', 'moddroid' ),
			'default'  => 'Name',
			),
			array(
			'id'       => 'exthemes_PublisherAPK',
			'type'     => 'text',
			'title'    => __( 'Publisher', 'moddroid' ),
			'default'  => 'Publisher',
			),
			array(
			'id'       => 'exthemes_GenreAPK',
			'type'     => 'text',
			'title'    => __( 'Genre', 'moddroid' ),
			'default'  => 'Genre',
			),
			array(
			'id'       => 'exthemes_SizeAPK',
			'type'     => 'text',
			'title'    => __( 'Size', 'moddroid' ),
			'default'  => 'Size',
			),
			array(
			'id'       => 'exthemes_VersionAPK',
			'type'     => 'text',
			'title'    => __( 'Version', 'moddroid' ),
			'default'  => 'Version',
			),
			array(
			'id'       => 'exthemes_UpdateAPK',
			'type'     => 'text',
			'title'    => __( 'Update', 'moddroid' ),
			'default'  => 'Update',
			),
			array(
			'id'       => 'exthemes_MODAPK',
			'type'     => 'text',
			'title'    => __( 'MOD', 'moddroid' ),
			'default'  => 'MOD',
			),
			array(
			'id'       => 'exthemes_GPSAPK',
			'type'     => 'text',
			'title'    => __( 'Get it On', 'moddroid' ),
			'default'  => 'Get it On',
			),
			array(
			'id'       => 'exthemes_Whats_NewAPK',
			'type'     => 'text',
			'title'    => __( 'Whats New', 'moddroid' ),
			'default'  => 'Whats New',
			),
			array(
			'id'       => 'exthemes_Useful_Sections',
			'type'     => 'text',
			'title'    => __( 'Useful Sections', 'moddroid' ),
			'default'  => 'Useful Sections',
			),
			array(
			'id'       => 'exthemes_About_Us',
			'type'     => 'text',
			'title'    => __( 'About Us', 'moddroid' ),
			'default'  => 'About Us',
			),
			array(
			'id'       => 'exthemes_download_thanks',
			'type'     => 'text',
			'title'    => __( 'Thank you for downloading', 'moddroid' ),
			'default'  => 'Thank you for downloading',
			),
			array(
			'id'       => 'exthemes_download_site',
			'type'     => 'text',
			'title'    => __( 'from our site. The following are available links. Just press the button and the file will be automatically downloaded', 'moddroid' ),
			'default'  => 'from our site. The following are available links. Just press the button and the file will be automatically downloaded',
			),
			array(
			'id'       => 'exthemes_download_faqs',
			'type'     => 'text',
			'title'    => __( 'Download FAQs', 'moddroid' ),
			'default'  => 'Download FAQs',
			),
			array(
			'id'       => 'exthemes_download_times_notice_1',
			'type'     => 'text',
			'title'    => __( 'Your link is almost ready, please wait a', 'moddroid' ),
			'default'  => 'Your link is almost ready, please wait a',
			),
			array(
			'id'       => 'exthemes_download_times_notice_2',
			'type'     => 'text',
			'title'    => __( 'seconds', 'moddroid' ),
			'default'  => 'seconds',
			),
			array(
			'id'       => 'exthemes_download_times_notice_3',
			'type'     => 'text',
			'title'    => __( 'If the download doesnt start in a few seconds', 'moddroid' ),
			'default'  => 'If the download doesnt start in a few seconds',
			),
			array(
			'id'       => 'exthemes_download_times_notice_4',
			'type'     => 'text',
			'title'    => __( 'click here', 'moddroid' ),
			'default'  => 'click here',
			),
			array(
			'id'       => 'exthemes_download_times_notice_5',
			'type'     => 'text',
			'title'    => __( 'You are downloading', 'moddroid' ),
			'default'  => 'You are downloading',
			),
			array(
			'id'       => 'exthemes_download_times_notice_6',
			'type'     => 'text',
			'title'    => __( 'You are now ready to download', 'moddroid' ),
			'default'  => 'You are now ready to download',
			),
			array(
			'id'       => 'exthemes_download_times_notice_7',
			'type'     => 'text',
			'title'    => __( 'for free. Here are some notes:', 'moddroid' ),
			'default'  => 'for free. Here are some notes:',
			),/* 
			array(
			'id'       => 'exthemes_comments_1',
			'type'     => 'text',
			'title'    => __( 'Leave a Comment', 'moddroid' ),
			'default'  => 'Leave a Comment',
			), */
			array(
			'id'       => 'exthemes_comments_2',
			'type'     => 'text',
			'title'    => __( 'Send Comment', 'moddroid' ),
			'default'  => 'Send Comment',
			),
			array(
			'id'       => 'exthemes_comments_3',
			'type'     => 'text',
			'title'    => __( 'Name', 'moddroid' ),
			'default'  => 'Name',
			),
			array(
			'id'       => 'exthemes_comments_4',
			'type'     => 'text',
			'title'    => __( 'Email', 'moddroid' ),
			'default'  => 'Email',
			),
			array(
			'id'       => 'exthemes_comments_5',
			'type'     => 'text',
			'title'    => __( 'Leave me a Comments', 'moddroid' ),
			'default'  => 'Leave me a Comments',
			),
			array(
			'id'       => 'exthemes_apk_info_1',
			'type'     => 'text',
			'title'    => __( 'Read', 'moddroid' ),
			'default'  => 'Read',
			),
			array(
			'id'       => 'exthemes_apk_info_2',
			'type'     => 'text',
			'title'    => __( 'views', 'moddroid' ),
			'default'  => 'views',
			),
			/* 
			array(
			'id'       => 'exthemes_apk_days_1',
			'type'     => 'text',
			'title'    => __( 'just now', 'moddroid' ),
			'default'  => 'just now',
			),
			array(
			'id'       => 'exthemes_apk_days_2',
			'type'     => 'text',
			'title'    => __( 'years ago', 'moddroid' ),
			'default'  => 'years ago',
			),
			array(
			'id'       => 'exthemes_apk_days_3',
			'type'     => 'text',
			'title'    => __( 'months ago', 'moddroid' ),
			'default'  => 'months ago',
			),
			array(
			'id'       => 'exthemes_apk_days_4',
			'type'     => 'text',
			'title'    => __( 'weeks ago', 'moddroid' ),
			'default'  => 'weeks ago',
			),
			array(
			'id'       => 'exthemes_apk_days_5',
			'type'     => 'text',
			'title'    => __( 'days ago', 'moddroid' ),
			'default'  => 'days ago',
			),
			array(
			'id'       => 'exthemes_apk_days_6',
			'type'     => 'text',
			'title'    => __( 'hours ago', 'moddroid' ),
			'default'  => 'hours ago',
			),
			array(
			'id'       => 'exthemes_apk_days_7',
			'type'     => 'text',
			'title'    => __( 'minutes ago', 'moddroid' ),
			'default'  => 'minutes ago',
			),
			array(
			'id'       => 'exthemes_apk_days_8',
			'type'     => 'text',
			'title'    => __( 'seconds ago', 'moddroid' ),
			'default'  => 'seconds ago',
			),
			*/
			array(
			'id'       => 'exthemes_apk_ago',
			'type'     => 'text',
			'title'    => __( ' ago', 'moddroid' ),
			'default'  => ' ago',
			),
)
) );